summaryrefslogtreecommitdiff
path: root/BaseTools/Source/Python
diff options
context:
space:
mode:
Diffstat (limited to 'BaseTools/Source/Python')
-rwxr-xr-xBaseTools/Source/Python/build/build.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/BaseTools/Source/Python/build/build.py b/BaseTools/Source/Python/build/build.py
index b0f333a2f0..7c2b96997a 100755
--- a/BaseTools/Source/Python/build/build.py
+++ b/BaseTools/Source/Python/build/build.py
@@ -82,7 +82,7 @@ TmpTableDict = {}
# If any of above environment variable is not set or has error, the build
# will be broken.
#
-def CheckEnvVariable():
+def CheckEnvVariables():
# check WORKSPACE
if "WORKSPACE" not in os.environ:
EdkLogger.error("build", ATTRIBUTE_NOT_AVAILABLE, "Environment variable not found",
@@ -2615,9 +2615,9 @@ def Main():
ExtraData="Please select one of: %s" % (' '.join(gSupportedTarget)))
#
# Check environment variable: EDK_TOOLS_PATH, WORKSPACE, PATH
#
- CheckEnvVariable()
+ CheckEnvVariables()
GlobalData.gCommandLineDefines.update(ParseDefines(Option.Macros))
Workspace = os.getenv("WORKSPACE")
@@ -2615,9 +2615,9 @@ def Main():
ExtraData="Please select one of: %s" % (' '.join(gSupportedTarget)))
#
- # Check environment variable: EDK_TOOLS_PATH, WORKSPACE, PATH
+ # Check environment variables: EDK_TOOLS_PATH, WORKSPACE, PATH, etc...
#